package com.bif.timecard.invoice;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>Instances of this class model the invoice meta data required for creating
 * an invoice.</p>
 * 
 * @author <a href="mailto:roderick.barnes@biftechnologies.com">Roderick L. Barnes, Sr.</a>
 */
public class DTOInvoiceMetaData implements Serializable {
	/**
	 * Serial number generated to support serialization of instances of this class.
	 */
	private static final long serialVersionUID = -7514206385608319431L;
	
	private String stringLogoLocation = "http://biftechnologies.com/wp-content/uploads/2019/08/xsi.jpg";
	
	public String getLogoLocation() {
		return this.stringLogoLocation;
	}
	
	public void setLogoLocation(String stringLogoLocationNew) {
		this.stringLogoLocation = stringLogoLocationNew;
	}

	/**
	 * Primary key for the invoice meta data record.
	 */
	private String stringInvoiceMetaDataID = "1";
	
	/**
	 * Candidate key for the invoice meta data record. This value will be unique in the
	 * table of records.
	 * 
	 * TODO: this name should dynamically obtain the sections and period
	 * for the invoice.
	 */
	private String stringInvoiceName = "XSI.HQSections.2019.06";
	
	/**
	 * <p>Member attribute for the DUNS number of the company that is submitting
	 * the invoice.</p>
	 * 
	 * <p>The Data Universal Numbering System, abbreviated as DUNS or D-U-N-S, 
	 * is a proprietary system developed and regulated by Dun & Bradstreet 
	 * that assigns a unique numeric identifier, referred to as a "DUNS number" 
	 * to a single business entity. It was introduced in 1963 to support D&B's 
	 * credit reporting practice.</p>
	 */
	private String stringDUNSNumber					=	"827980942";
	
	private String stringRequisitionNumber			=	"1044806258";
	private String stringContractNumber				=	"ContractNumber1234567890";
	private String stringOrderNumber				=	"19AQMM18F5384";
	private String stringTaskOrderNumber			=	"TaskOrderNumber.1234567890";
	private List<String> listOfStringFAR			=	new ArrayList<String>();
	private String stringBillingPeriod				=	"Undefined";
	/*
	 * TODO: Does the invoice number need to be dynamically determined by
	 * the period and the number of existing records for the period?
	 */
	private String stringInvoiceNumber				=	"XTR-06-19-1";
	private String stringPaymentTerms				=	"Net 10-15";
	private String stringDateOfInvoice				=	"Undefined";
	private double doubleTotalHours					=	3835.25;
	private double doubleTotalInvoiceAmount			=	1000000.00;

	private String stringVendorAddress				=	"Xtreme Solutions, Inc.\n2859 Paces Ferry Rd SE, Suite 1100\nAtlanta, GA 30339-6207\n(404)883-2000";
	private String stringCustomerBillToAddress		=	"Department Of State\nGlobal Financial Operations (RM/GFS/GFO)\nOffice of Claims (GFO/C)\nCharleston Financial Service Center\nPost Office Box 15008\nCharleston, SC 29415-5008";
	private String stringRemitToAddress				=	"Xtreme Solutions, Inc.\nAttn: Hervia M. Ingram, Jr.\n2859 Paces Ferry Road, Suite 1100\nAtlanta, GA 30339-6207\nhingram@xtremesolutions-inc.com\n404-883-2000";
	private String stringRemitContactInformation	=	"Devance Boseman, Account Manager, 2859 Paces Ferry Road, Suite 1100, Atlanta, GA 30339-6207\naccounting@xtremesolutions-inc.com\n404-883-2000";
	private String stringRemitMethodInformation		=	"PLEASE REMIT VIA ACH\nBank: Bank of America\nABA# 061000052\nAccount# 334008719825";
	
	public void setInvoiceMetaDataID(String stringInvoiceMetaDataIDNew) {
		this.stringInvoiceMetaDataID = stringInvoiceMetaDataIDNew;
	}
	
	public String getInvoiceMetaDataID() {
		return this.stringInvoiceMetaDataID;
	}
	
	public void setInvoiceName(String stringInvoiceNameNew) {
		this.stringInvoiceName = stringInvoiceNameNew;
	}
	
	public String getInvoiceName() {
		return this.stringInvoiceName;
	}
	
	public void setDUNSNumber(String stringDUNSNumberNew) {
		this.stringDUNSNumber = stringDUNSNumberNew;
	}
	
	public String getDUNSNumber() {
		return this.stringDUNSNumber;
	}
	
	public void setRequisitionNumber(String stringRequisitionNumberNew) {
		this.stringRequisitionNumber = stringRequisitionNumberNew;
	}
	
	public String getRequisitionNumber() {
		return this.stringRequisitionNumber;
	}
	
	public void setContractNumber(String stringContractNumberNew) {
		this.stringContractNumber = stringContractNumberNew;
	}
	
	public String getContractNumber() {
		return this.stringContractNumber;
	}
	
	public void setOrderNumber(String stringOrderNumberNew) {
		this.stringOrderNumber = stringOrderNumberNew;
	}
	
	public String getOrderNumber() {
		return this.stringOrderNumber;
	}
	
	public void setTaskOrderNumber(String stringTaskOrderNumberNew) {
		this.stringTaskOrderNumber = stringTaskOrderNumberNew;
	}
	
	public String getTaskOrderNumber() {
		return this.stringTaskOrderNumber;
	}
	
	public List<String> getFARs() {
		return this.listOfStringFAR;
	}
	
	public void setBillingPeriod(String stringBillingPeriodNew) {
		this.stringBillingPeriod = stringBillingPeriodNew;
	}
	
	public String getBillingPeriod() {
		return this.stringBillingPeriod;
	}
	
	public void setInvoiceNumber(String stringInvoiceNumberNew) {
		this.stringInvoiceNumber = stringInvoiceNumberNew;
	}
	
	public String getInvoiceNumber() {
		return this.stringInvoiceNumber;
	}
	
	public void setPaymentTerms(String stringPaymentTermsNew) {
		this.stringPaymentTerms = stringPaymentTermsNew;
	}
	
	public String getPaymentTerms() {
		return this.stringPaymentTerms;
	}
	
	public void setDateOfInvoice(String stringDateOfInvoiceNew) {
		this.stringDateOfInvoice = stringDateOfInvoiceNew;
	}
	
	public String getDateOfInvoice() {
		return this.stringDateOfInvoice;
	}
	
	public void setTotalHours(double doubleTotalHoursNew) {
		this.doubleTotalHours = doubleTotalHoursNew;
	}
	
	public double getTotalHours() {
		return this.doubleTotalHours;
	}
	
	public void setTotalInvoiceAmount(double doubleTotalInvoiceAmountNew) {
		this.doubleTotalInvoiceAmount = doubleTotalInvoiceAmountNew;
	}
	
	public double getTotalInvoiceAmount() {
		return this.doubleTotalInvoiceAmount;
	}

	/**
	 * @return the stringVendorAddress
	 */
	public String getVendorAddress() {
		return stringVendorAddress;
	}

	/**
	 * @param stringVendorAddress the stringVendorAddress to set
	 */
	public void setVendorAddress(String stringVendorAddressNew) {
		this.stringVendorAddress = stringVendorAddressNew;
	}

	/**
	 * @return the stringCustomerBillToAddress
	 */
	public String getStringCustomerBillToAddress() {
		return stringCustomerBillToAddress;
	}

	/**
	 * @param stringCustomerBillToAddress the stringCustomerBillToAddress to set
	 */
	public void setCustomerBillToAddress(String stringCustomerBillToAddressNew) {
		this.stringCustomerBillToAddress = stringCustomerBillToAddressNew;
	}

	/**
	 * @return the stringRemitToAddress
	 */
	public String getRemitToAddress() {
		return stringRemitToAddress;
	}

	/**
	 * @param stringRemitToAddress the stringRemitToAddress to set
	 */
	public void setRemitToAddress(String stringRemitToAddressNew) {
		this.stringRemitToAddress = stringRemitToAddressNew;
	}

	/**
	 * @return the stringRemitContactInformation
	 */
	public String getRemitContactInformation() {
		return stringRemitContactInformation;
	}

	/**
	 * @param stringRemitContactInformation the stringRemitContactInformation to set
	 */
	public void setRemitContactInformation(String stringRemitContactInformationNew) {
		this.stringRemitContactInformation = stringRemitContactInformationNew;
	}

	/**
	 * @return the stringRemitMethodInformation
	 */
	public String getRemitMethodInformation() {
		return stringRemitMethodInformation;
	}

	/**
	 * @param stringRemitMethodInformation the stringRemitMethodInformation to set
	 */
	public void setRemitMethodInformation(String stringRemitMethodInformationNew) {
		this.stringRemitMethodInformation = stringRemitMethodInformationNew;
	}
	
	public String toString() {
		return this.getContractNumber() + ":" + this.getInvoiceName();
	}
}
