package com.bif.timecard.loader;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Date;

import javax.sql.RowSet;

import com.bif.timecard.invoice.DTOInvoiceMetaData;

import oracle.jdbc.rowset.OracleCachedRowSet;

public class DAOTimeCard {
	/**
	 *  non-javadoc, see com.bif.wmsn.server.DAOBase for documentation
	 */
	public static String getSQLResource(@SuppressWarnings("rawtypes") Class classX, String stringResourceName) throws IOException {
		InputStream inputStream = classX.getResourceAsStream(stringResourceName);
		InputStreamReader inputStreamReader = new InputStreamReader(inputStream);
		BufferedReader bufferedReader = new BufferedReader(inputStreamReader);
		
		String stringSQLResource = "";
		String stringLineOfText = null;
		while ((stringLineOfText = bufferedReader.readLine()) != null) {
			stringSQLResource += stringLineOfText + "\n";
		}
		
		return stringSQLResource;
	}

	public DTOInvoiceMetaData getInvoiceMetaData(String stringBillingPeriodID) throws Exception {
		Connection connection = null;
		PreparedStatement preparedStatement = null;
		
		/**
		 * Step 1: Get the SQL statement that will be used to acquire the
		 * invoice metadata for a billing period.
		 */
		String stringSQL = DAOTimeCard.getSQLResource(DAOTimeCard.class, "sql_resource_get_invoice_metadata.sql");
		DTOInvoiceMetaData dtoInvoiceMetaDataTemp = null;
		
		try {
			/**
			 *  Step 2: Connect to the time card database.
			 */
			connection = DriverManager.getConnection(
					"jdbc:oracle:thin:@//jarvis.ctrlzjj4vv8c.us-east-1.rds.amazonaws.com:1521/bifdevdb",
					"insight",
					"oracle"
				);
			
			/**
			 *  Step 3: Prepare statement for getting metadata.
			 */
			preparedStatement = connection.prepareStatement(stringSQL);
			preparedStatement.setString(1, stringBillingPeriodID);
			
			/**
			 *  Step 4: Move the invoice metadata into a data transfer object.
			 */
			ResultSet resultSet = preparedStatement.executeQuery();
			while (resultSet.next()) {
				dtoInvoiceMetaDataTemp = new DTOInvoiceMetaData();
				dtoInvoiceMetaDataTemp.setInvoiceMetaDataID(resultSet.getString("invoice_metadata_id"));
				dtoInvoiceMetaDataTemp.setBillingPeriod(stringBillingPeriodID);
				dtoInvoiceMetaDataTemp.setInvoiceName(resultSet.getString("invoice_name"));
				dtoInvoiceMetaDataTemp.setDUNSNumber(resultSet.getString("duns_number"));
				dtoInvoiceMetaDataTemp.setRequisitionNumber(resultSet.getString("requisition_number"));
				dtoInvoiceMetaDataTemp.setContractNumber(resultSet.getString("contract_number"));
				dtoInvoiceMetaDataTemp.setOrderNumber(resultSet.getString("order_number"));
				dtoInvoiceMetaDataTemp.setTaskOrderNumber(resultSet.getString("task_order_number"));
				dtoInvoiceMetaDataTemp.setCustomerBillToAddress(resultSet.getString("customer_bill_to_address"));
				dtoInvoiceMetaDataTemp.setInvoiceNumber(resultSet.getString("invoice_number"));
				dtoInvoiceMetaDataTemp.setPaymentTerms(resultSet.getString("payment_terms"));
				dtoInvoiceMetaDataTemp.setDateOfInvoice(resultSet.getString("date_of_invoice"));
				dtoInvoiceMetaDataTemp.setVendorAddress(resultSet.getString("vendor_address"));
				dtoInvoiceMetaDataTemp.setCustomerBillToAddress(resultSet.getString("customer_bill_to_address"));
				dtoInvoiceMetaDataTemp.setRemitToAddress(resultSet.getString("remit_to_address"));
				dtoInvoiceMetaDataTemp.setRemitContactInformation(resultSet.getString("remit_contract_information"));
				dtoInvoiceMetaDataTemp.setRemitMethodInformation(resultSet.getString("remit_method_information"));
			}
						
			/**
			 *  Step 5: Close the statement and the connection.
			 */
			preparedStatement.close();
			preparedStatement = null;
			connection.close();
			connection = null;
		} catch (SQLException exception) {
			exception.printStackTrace();
		} finally {
			if (connection != null) {
				try {
					connection.close();
				} catch (SQLException exception) {
					exception.printStackTrace();
				}
			}
		}
		
		/**
		 * Step 6: Return the data.
		 */
		return dtoInvoiceMetaDataTemp;
	}
	
	public OracleCachedRowSet getSections(String stringPeriodID) throws Exception {
		Connection connection = null;
		OracleCachedRowSet oracleCachedRowSet = null;
		PreparedStatement preparedStatement = null;
		
		// Step 1: Get the SQL statement that will be used to load the invoice data.
		String stringSQL = DAOTimeCard.getSQLResource(DAOTimeCard.class, "sql_resource_get_sections.sql");

		try {
			// Step 3.1: Connect to the time card database.
			connection = DriverManager.getConnection(
					"jdbc:oracle:thin:@//jarvis.ctrlzjj4vv8c.us-east-1.rds.amazonaws.com:1521/bifdevdb",
					"insight",
					"oracle"
				);
			
			// Step 3.2: Prepare to get invoice details.
			preparedStatement = connection.prepareStatement(stringSQL);
			preparedStatement.setString(1, stringPeriodID);
			
			// Step 3.3: Execute the query and cache the results.
			ResultSet resultSet = preparedStatement.executeQuery();
			oracleCachedRowSet = new OracleCachedRowSet();
			oracleCachedRowSet.populate(resultSet);
						
			// Step 3.4: Close the statement and the connection.
			preparedStatement.close();
			preparedStatement = null;
			connection.close();
			connection = null;
		} catch (SQLException exception) {
			exception.printStackTrace();
		} finally {
			if (connection != null) {
				try {
					connection.close();
				} catch (SQLException exception) {
					exception.printStackTrace();
				}
			}
		}

		return oracleCachedRowSet;
	}
	
	public OracleCachedRowSet getInvoiceRowSet(String stringBillingPeriodID, String stringInvoiceSectionID) throws Exception {
		Connection connection = null;
		OracleCachedRowSet oracleCachedRowSet = null;
		PreparedStatement preparedStatement = null;
		
		// Step 1: Get the SQL statement that will be used to load the invoice data.
		String stringSQL = DAOTimeCard.getSQLResource(DAOTimeCard.class, "sql_resource_get_invoice_details.sql");
		
		// Step 2: Load the Oracle JDBC driver into the virtual machine.
		Class.forName("oracle.jdbc.OracleDriver");
		
		try {
			// Step 3.1: Connect to the time card database.
			connection = DriverManager.getConnection(
					"jdbc:oracle:thin:@//jarvis.ctrlzjj4vv8c.us-east-1.rds.amazonaws.com:1521/bifdevdb",
					"insight",
					"oracle"
				);
			
			// Step 3.2: Prepare to get invoice details.
			preparedStatement = connection.prepareStatement(stringSQL);
			preparedStatement.setString(1, stringBillingPeriodID);
			preparedStatement.setString(2, stringInvoiceSectionID);
			
			// Step 3.3: Execute the query and cache the results.
			ResultSet resultSet = preparedStatement.executeQuery();
			oracleCachedRowSet = new OracleCachedRowSet();
			oracleCachedRowSet.populate(resultSet);
						
			// Step 3.4: Close the statement and the connection.
			preparedStatement.close();
			preparedStatement = null;
			connection.close();
			connection = null;
		} catch (SQLException exception) {
			exception.printStackTrace();
		} finally {
			if (connection != null) {
				try {
					connection.close();
				} catch (SQLException exception) {
					exception.printStackTrace();
				}
			}
		}
		
		// Step 4: Return the cached rowset.
		return oracleCachedRowSet;
	}
	
	/**
	 * 
	 * @param arrayOfStringArgument
	 */
	public static void main(String[] arrayOfStringArgument) throws Exception {
		DAOTimeCard daoTimeCard = new DAOTimeCard();
		RowSet rowSet = daoTimeCard.getInvoiceRowSet("2019.03.01", "2019.04.01");
		
		rowSet.beforeFirst();
		while (rowSet.next()) {
			System.out.format("Employee: %25s\n", rowSet.getString(2));
		}
	}
}
