package com.bif.timecard.loader;

import java.sql.ResultSetMetaData;
import java.sql.SQLException;

import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CreationHelper;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import oracle.jdbc.rowset.OracleCachedRowSet;

/**
 * This utility class converts collections and {@code RowSet} objects
 * into Excel spreadsheets.
 * @author <a href="mailto:roderick.barnes@biftechnologies.com">Roderick L. Barnes, Sr.</a>
 */
public class SheetMaker {
	/**
	 * member attribute providing a cursor/pointer into the {@code RowSet} current row.
	 */
	private int intRowIndex = 0;
	
	/**
	 * Simple constructor for new instances of this class.
	 */
	public SheetMaker() {
		
	}
	
	/**
	 * Returns the current row index.
	 * @return the current row index.
	 */
	public int getRowIndex() {
		return this.intRowIndex;
	}
	
	/**
	 * Sets the current row index.
	 * @param intRowIndexNew the new row index.
	 */
	public void setRowIndex(int intRowIndexNew) {
		this.intRowIndex = intRowIndexNew;
	}
		
	/**
	 * Creates an Excel workbook using the given {@code RowSet} object as a source for column headers
	 * and data. The name of the sheet will be based on {@code stringSheetName}.
	 * @param stringSheetName name of the sheet in the returned workbook.
	 * @param oracleCachedRowSetTemp {@code RowSet} object that will be used to get the sheet data.
	 * @return Excel workbook
	 * @throws Exception thrown if there is a problem access the {@code RowSet} data or creating the workbook.
	 */
	public XSSFWorkbook createWorkbook(String stringSheetName, OracleCachedRowSet oracleCachedRowSetTemp) throws Exception {
		XSSFWorkbook xssfWorkbook = new XSSFWorkbook();
		Sheet sheet = xssfWorkbook.createSheet(stringSheetName);
		CreationHelper creationHelper = xssfWorkbook.getCreationHelper();
		
		this.createHeaders(sheet, creationHelper, oracleCachedRowSetTemp);
		this.createBody(sheet, creationHelper, oracleCachedRowSetTemp);
		
		return xssfWorkbook;
	}
	
	public XSSFWorkbook createPivotWorkbook(String stringSheetName, OracleCachedRowSet oracleCachedRowSetTemp) throws Exception {
		XSSFWorkbook xssfWorkbook = new XSSFWorkbook();
		Sheet sheetPivot = xssfWorkbook.createSheet("BrainJack Pivot Table");
		Sheet sheet = xssfWorkbook.createSheet(stringSheetName);
		CreationHelper creationHelper = xssfWorkbook.getCreationHelper();
		
		this.createHeaders(sheet, creationHelper, oracleCachedRowSetTemp);
		this.createBody(sheet, creationHelper, oracleCachedRowSetTemp);
		
		return xssfWorkbook;
	}
	
	public void createHeaders(Sheet sheet, CreationHelper creationHelper, OracleCachedRowSet oracleCachedRowSetTemp) throws SQLException {
		/**
		 * iterate through the columns
		 */
		Row rowColumnHeaders = sheet.createRow(this.getRowIndex());
		ResultSetMetaData resultSetMetaData = oracleCachedRowSetTemp.getMetaData();
		oracleCachedRowSetTemp.beforeFirst();

		for (int intColumnIndex = 1; intColumnIndex <= resultSetMetaData.getColumnCount(); intColumnIndex++) {
			String stringColumnName = resultSetMetaData.getColumnName(intColumnIndex);
			
			/**
			 * add the column headers
			 */
			Cell cellColumnHeader = rowColumnHeaders.createCell(intColumnIndex - 1);
			cellColumnHeader.setCellValue(creationHelper.createRichTextString(stringColumnName));
		}
	}

	public void createBody(Sheet sheet, CreationHelper creationHelper, OracleCachedRowSet oracleCachedRowSetTemp) throws SQLException {
		ResultSetMetaData resultSetMetaData = oracleCachedRowSetTemp.getMetaData();
		oracleCachedRowSetTemp.beforeFirst();

		while (oracleCachedRowSetTemp.next()) {
			this.setRowIndex(this.getRowIndex() + 1);
			
			Row rowData = sheet.createRow(this.getRowIndex());
			for (int intColumnIndex = 1; intColumnIndex <= resultSetMetaData.getColumnCount(); intColumnIndex++) {
				String stringCellData = "";
				
				stringCellData = oracleCachedRowSetTemp.getString(intColumnIndex);
				
				/**
				 * add the column data
				 */
				Cell cellData = rowData.createCell(intColumnIndex - 1);
				cellData.setCellValue(creationHelper.createRichTextString(stringCellData));				
			}
		}
	}
}