package com.bif.timecard.loader.enumeration;

/**
 * <p>This enumeration provides indices to the tokens loaded from a time card data file.</p>
 * 
 * @author <a href="mailto:roderick.barnes@biftechnologies.com">Roderick L. Barnes, Sr.</a>
 */
public enum CMTTokenIndex {
	/**
	 * The employee identifier in a line of time card data.
	 */
	EmployeeIdentifier,
	
	/**
	 * Last name of the employee in a line of time card data.
	 */
	LastName,
	
	/**
	 * First name of the employee in a line of time card data.
	 */
	FirstName,
	
	/**
	 * Amount of time recorded for the event.
	 */
	EventDuration,
	
	/**
	 * Date on which the employee spent time of specified PayType on the contract.
	 */
	EventDate,
	
	/**
	 * Day of the week for the given date. This field is ignored in data load process.
	 */
	EventDayOfWeek,
	
	/**
	 * Pay type associated with a line of data in the time card
	 * date file.
	 */
	EventType,
		
	/**
	 * Project identifier for the line of time card data.
	 */
	ProjectID,
	
	/**
	 * Name of the project for the time recorded.
	 */
	ProjectName,
	
	/**
	 * Identifier for the labor category.
	 */
	LaborCategoryID,
	
	/**
	 * Name of the labor category.
	 */
	LaborCategoryName,
	
	/**
	 * Identifier for the department.
	 */
	DepartmentID,
	
	/**
	 * Name of the department.
	 */
	DepartmentName		
}