package com.bif.timecard.loader.enumeration;

import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * <p>This enumeration provides configuration properties for the BrainJack&trade; Time Card
 * data loader.</p>
 * 
 * @author <a href="mailto:roderick.barnes@biftechnologies.com">Roderick L. Barnes, Sr.</a>
 */
public enum ConfigurationProperty {
	/**
	 * Company identifier property. This value is used to partition time and attendance data by
	 * company.
	 */
	CompanyID("Company ID","XSI"),
	
	/**
	 * Billing period identifier property. This value is used to determine which partition of a
	 * company's historical data will be purged in preparation for a data load.
	 */
	BillingPeriodID("Billing Period ID",""),
	
	/**
	 * This property corresponds to the path of the data file on the loading client.
	 */
	DataFilePath("Time Card Data File Path",""),
	
	/**
	 * This property corresponds to the JDBC URL for the BrainJack&trade; Time Card repository.
	 */
	JDBCURL("Database URL","jdbc:oracle:thin:@//jarvis.ctrlzjj4vv8c.us-east-1.rds.amazonaws.com:1521/bifdevdb"),
	
	/**
	 * JDBC driver class for the DAO.
	 */
	JDBCDriverClass("JDBC Driver Class","oracle.jdbc.OracleDriver"),
	
	/**
	 * Database account user name.
	 */
	JDBCUsername("Database Account User","timecard"),
	
	/**
	 * Enum entry for the database password.
	 */
	JDBCPassword("Database Account Password","oracle007");
	
	private String stringPrompt;
	private String stringDefault;
	private String stringValue	=	null;
	private boolean booleanSetInConfigurationFile = false;
	private SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy.MM");
	
	private SimpleDateFormat getDateFormatter() {
		return this.simpleDateFormat;
	}
	
	private void setPrompt(String stringPromptNew) {
		this.stringPrompt = stringPromptNew;
	}
	
	public String getPrompt() {
		return this.stringPrompt;
	}
	
	private void setDefault(String stringDefaultNew) {
		this.stringDefault = stringDefaultNew;
	}
	
	public String getDefault() {
		return this.stringDefault;
	}
	
	public void setValue(String stringValueNew) {
		this.stringValue = stringValueNew;
		
		if (this.name().equalsIgnoreCase("BillingPeriodID")) {
			String stringDefaultDataFilePath = "./data/company_id." + ConfigurationProperty.BillingPeriodID.getValue() + ".csv";
			stringDefaultDataFilePath = stringDefaultDataFilePath.replace("company_id", ConfigurationProperty.CompanyID.getValue().toLowerCase().trim());
			ConfigurationProperty.DataFilePath.setDefault(stringDefaultDataFilePath);
		}
	}
	
	public String getValue() {
		if (this.stringValue != null) { 
			return this.stringValue;
		} else {
			return this.stringDefault;
		}
	}
	
	public boolean isSetInConfigurationFile() {
		return this.booleanSetInConfigurationFile;
	}
	
	public void setInConfigurationFile(boolean booleanSetInCongurationFileNew) {
		this.booleanSetInConfigurationFile = booleanSetInCongurationFileNew;
	}
	
	private ConfigurationProperty(String stringPromptNew, String stringDefaultNew) {
		this.setPrompt(stringPromptNew);
		this.setDefault(stringDefaultNew);
		
		Date dateDefaultBillingPeriodID = new Date();
		String stringDefaultBillingPeriodID = this.getDateFormatter().format(dateDefaultBillingPeriodID);

		if (this.name().equalsIgnoreCase("BillingPeriodID")) {
			this.setDefault(stringDefaultBillingPeriodID);
		}
		
		if (this.name().equalsIgnoreCase("DataFilePath")) {
			String stringDefaultDataFilePath = "./data/company_id." + stringDefaultBillingPeriodID + ".csv";
			this.setDefault(stringDefaultDataFilePath);
		}
	}
}