package com.bif.timecard.loader.enumeration;

/**
 * <p>This enumeration provides pay types for the BrainJack Time Tracking application.</p>
 * 
 * @author <a href="mailto:roderick.barnes@biftechnologies.com">Roderick L. Barnes, Sr.</a>
 */
public enum PayType {
	Bereavement("Bereavement"),
	Break("Break"),
	Holiday("Holiday"),
	JuryDuty("Jury Duty"),
	Meal("Meal"),
	MilitaryLeave("Military Leave"),
	Sick("Sick"),
	UnpaidTime("Unpaid Time"),
	Vacation("Vacation"),
	WeatherGovernmentClosure("Weather-Government Closure"),
	WorkWeatherClosure("Work Weather Closure"),
	Work("Work");
	
	/**
	 * Enumeration entry attribute used to hold the caption for the pay type.
	 */
	private String stringCaption;
	
	/**
	 * Sets the caption for the pay type.
	 * @param stringCaptionNew caption that will be used in user-facing iterfaces
	 */
	private void setCaption(String stringCaptionNew) {
		this.stringCaption = stringCaptionNew;
	}
	
	/**
	 * Returns the caption associated with the pay type.
	 * @return the caption associated with the pay type.
	 */
	public String getCaption() {
		return this.stringCaption;
	}
	
	/**
	 * Returns the {@code PayType} associated with the provided caption. The
	 * comparison of pay type captions with {@code stringCaptionNew} is not
	 * case sensitive.
	 * @param stringCaptionNew caption used to find a {@code PayType} enumeration
	 * entry
	 * @return {@code PayType} object associated with the provided caption.
	 */
	public static PayType captionToPayType(String stringCaptionNew) {
		stringCaptionNew = stringCaptionNew.replace(" -", "-");
		
		/**
		 * CMT data files have event types (pay types) that are not in our
		 * enumeration. In order to get a match we will have to performa a
		 * transform on the caption. Unscheduled Vacation -> Vacation,
		 * Scheduled Sick -> Sick.
		 * 
		 * Future releases will benefit from a transformation table.
		 */
		if (stringCaptionNew.equalsIgnoreCase("Unscheduled Vacation")) {
			return PayType.Vacation;
		}
		if (stringCaptionNew.equalsIgnoreCase("Scheduled Sick")) {
			return PayType.Sick;
		}
		
		
		if (stringCaptionNew.equalsIgnoreCase("Unpaid")) {
			stringCaptionNew = "Unpaid Time";
		}
		
		PayType payTypeReturnValue = null;
		
		boolean booleanFound = false;
		for (PayType payTypeTemp : PayType.values()) {
			if (payTypeTemp.getCaption().equalsIgnoreCase(stringCaptionNew)) {
				payTypeReturnValue = payTypeTemp;
				booleanFound = true;
				break;
			}
		}
		
		if (booleanFound == false) {
			System.out.println("Unrecognized Pay Type: " + stringCaptionNew);
		}
		
		return payTypeReturnValue;
	}
	
	/**
	 * Constructor for entries in the {@code PayType} enumeration.
	 * @param stringCaptionNew caption that will be used in user-facing iterfaces
	 */
	private PayType(String stringCaptionNew) {
		this.setCaption(stringCaptionNew);
	}
}
