package com.bif.timecard.loader.enumeration;

/**
 * <p>This enumeration provides indices to the tokens loaded from a time card data file.</p>
 * 
 * @author <a href="mailto:roderick.barnes@biftechnologies.com">Roderick L. Barnes, Sr.</a>
 */
public enum TokenIndex {
	/**
	 * The employee identifier in a line of time card data.
	 */
	EmployeeIdentifier,
	
	/**
	 * Last name of the employee in a line of time card data.
	 */
	FirstName,
	
	/**
	 * First name of the employee in a line of time card data.
	 */
	LastName,
	
	/**
	 * Date on which the employee spent time of specified PayType on the contract.
	 */
	EventDate,
	
	/**
	 * Pay type associated with a line of data in the time card
	 * date file.
	 */
	PayType,
	
	/**
	 * Amount of time that can be billed for on the contract.
	 */
	RegularDuration,
	
	/**
	 * Amount of time on the contract that cannot be billed for.
	 */
	UnpaidDuration,
	
	/**
	 * Total amount of time for which the customer will be billed
	 * for the given labor category in the given department on the given
	 * project.
	 */
	TotalPaidDuration,
	
	/**
	 * Project identifier for the line of time card data.
	 */
	ProjectID,
	
	/**
	 * Name of the project for the time recorded.
	 */
	ProjectName,
	
	/**
	 * Labor category identifer
	 */
	LaborCategoryID,

	/**
	 * Human-readable name for the labor category
	 */
	LaborCategoryName,
	DepartmentID,
	DepartmentName,
	HourlyRate;		
}