/**
* This anonymous block facilitates the saving of time card
* data into the BrainJack Time Card database.
*/
DECLARE
	varchar2_company_id				VARCHAR2(100)	:=	?;
	varchar2_employee_id			VARCHAR2(100)	:=	?;
	varchar2_first_name				VARCHAR2(100)	:=	?;
	varchar2_last_name				VARCHAR2(100)	:=	?;
	varchar2_event_date				VARCHAR2(100)	:=	?;
	varchar2_event_type				VARCHAR2(100)	:=	?;
	number_regular_duration			NUMBER			:=	?;
	number_unpaid_duration			NUMBER			:=	?;
	number_total_paid_duration		NUMBER			:=	?;
	varchar2_project_id				VARCHAR2(100)	:=	?;
	varchar2_project_name			VARCHAR2(100)	:=	?;
	varchar2_labor_category_id		VARCHAR2(100)	:=	?;
	varchar2_department_id			VARCHAR2(100)	:=	?;
	varchar2_department_name		VARCHAR2(100)	:=	?;
	number_hourly_rate				NUMBER			:=	?;
	
	varchar2_billing_period_id		VARCHAR2(100);
	
	record_labor_category			TIMECARD.LABOR_CATEGORY%ROWTYPE;
BEGIN
	/**
	* Step 1: The event date (the date that the event took place on) may be in
	* a format that does not automatically parse to a year in the 21st
	* century. We can use a simple check to see which format we have and
	* then use it to compute the billing period id from the event date.
	*/
	IF (LENGTH(varchar2_event_date) = 10) THEN
		varchar2_billing_period_id		:=	TO_CHAR(TO_DATE(varchar2_event_date,'mm/dd/yyyy'),'yyyy.mm');
	ELSE
		varchar2_billing_period_id		:=	TO_CHAR(TO_DATE(varchar2_event_date,'mm/dd/yy'),'yyyy.mm');
	END IF;
	
	/**
	* Step 2: Attempt to get the labor category record given (1) a billing period
	* identifier and (2) a labor category identifier. The table timecard.labor_category
	* has a compound primary key: (i) labor_category_id and (ii) billing_period_id.
	*/
	record_labor_category	:=		TIMECARD.TIME_CARD.get_labor_category(
					varchar2_billing_period_id,
					varchar2_labor_category_id
				);
	IF (record_labor_category.labor_category_id IS NULL) THEN
		RAISE_APPLICATION_ERROR(-20007, 'Labor category not found using billing period id ' || varchar2_billing_period_id || ' and labor category id ' || varchar2_labor_category_id || '.');
	END IF;
	
	/**
	* Step 3: Insert the time card record into the BrainJack Time Card
	* datbase.
	*/
	INSERT INTO timecard.time_card_fact tcf (
		tcf.company_id,
		tcf.employee_id,
		tcf.first_name,
		tcf.last_name,
		tcf.event_date,
		tcf.event_type,
		tcf.regular_duration,
		tcf.unpaid_duration,
		tcf.total_paid_duration,
		tcf.project_id,
		tcf.project_name,
		tcf.labor_category_id,
		tcf.department_id,
		tcf.department_name,
		tcf.hourly_rate
	) VALUES (
		varchar2_company_id,
		varchar2_employee_id,
		varchar2_first_name,
		varchar2_last_name,
		TO_DATE(varchar2_event_date,'mm/dd/yyyy'),
		varchar2_event_type,
		number_regular_duration,
		number_unpaid_duration,
		number_total_paid_duration,
		varchar2_project_id,
		varchar2_project_name,
		varchar2_labor_category_id,
		varchar2_department_id,
		varchar2_department_name,
		number_hourly_rate
	);	
EXCEPTION
	WHEN OTHERS THEN
		RAISE;
END;	