WITH
	FUNCTION get_billable_hours(varchar_employee_id IN VARCHAR, varchar_billing_period_id IN VARCHAR) RETURN NUMBER IS
			number_employee_hours_total       NUMBER  := 0;
	            
			CURSOR cursor_billable_hours(varchar_employee_id IN VARCHAR, varchar_billing_period_id IN VARCHAR) IS
				SELECT
					NVL(SUM(tcf.total_paid_duration),0)		AS  employee_hours
				FROM
					timecard.time_card_fact   tcf
				WHERE
					tcf.employee_id							=   varchar_employee_id
				AND TO_CHAR(tcf.event_date,'yyyy.mm')		=   varchar_billing_period_id
				AND	tcf.event_type							NOT IN ('Vacation','Sick','Holiday')
				AND TO_CHAR(tcf.event_date,'yyyy.mm.dd')	NOT IN (
					SELECT
						TO_CHAR(bnpe.event_date,'yyyy.mm.dd')
					FROM
						timecard.billable_non_profit_event	bnpe
				);
		BEGIN
			FOR record_billable_hours IN cursor_billable_hours(varchar_employee_id, varchar_billing_period_id) LOOP
				number_employee_hours_total   :=  number_employee_hours_total + record_billable_hours.employee_hours;
			END LOOP;
			RETURN number_employee_hours_total;
		END;
	FUNCTION get_billable_non_profit_hours(varchar_employee_id IN VARCHAR, varchar_billing_period_id IN VARCHAR) RETURN NUMBER IS
			number_employee_hours_total       NUMBER  := 0;
	            
			CURSOR cursor_non_profit_billable_hrs(varchar_employee_id IN VARCHAR, varchar_billing_period_id IN VARCHAR) IS
				SELECT
					NVL(SUM(tcf.total_paid_duration),0)		AS  employee_hours
				FROM
					timecard.time_card_fact   tcf
				WHERE
					tcf.employee_id							=   varchar_employee_id
				AND	tcf.event_type							NOT IN ('Vacation','Sick','Holiday')
				AND TO_CHAR(tcf.event_date,'yyyy.mm')		=   varchar_billing_period_id
				AND TO_CHAR(tcf.event_date,'yyyy.mm.dd')	IN (
					SELECT
						TO_CHAR(bnpe.event_date,'yyyy.mm.dd')
					FROM
						timecard.billable_non_profit_event	bnpe
				);
		BEGIN
			FOR record_non_profit_billable_hrs IN cursor_non_profit_billable_hrs(varchar_employee_id, varchar_billing_period_id) LOOP
				number_employee_hours_total   :=  number_employee_hours_total + record_non_profit_billable_hrs.employee_hours;
			END LOOP;
			RETURN number_employee_hours_total;
		END;
	FUNCTION get_unit_cost(varchar_billing_period_id IN VARCHAR2, varchar_labor_category_id IN VARCHAR2) RETURN NUMBER IS
			number_calculated_unit_cost NUMBER  :=  -1.00;
			
			CURSOR cursor_bill_rate (varchar_billing_period_id IN VARCHAR2, varchar_labor_category_id IN VARCHAR2) IS
				SELECT
					lc.labor_category_id,
					lc.labor_category_name,
					lc.bill_rate
				FROM
					timecard.labor_category	lc
				WHERE
					lc.billing_period_id		=	varchar_billing_period_id
				AND	lc.labor_category_id		=	varchar_labor_category_id;
		BEGIN
			FOR record_bill_rate IN cursor_bill_rate(varchar_billing_period_id, varchar_labor_category_id) LOOP
				number_calculated_unit_cost :=  record_bill_rate.bill_rate;
			END LOOP;
            
			RETURN number_calculated_unit_cost;
		END;
	FUNCTION get_non_profit_unit_cost(varchar_billing_period_id IN VARCHAR2, varchar_labor_category_id IN VARCHAR2) RETURN NUMBER IS
			number_calculated_unit_cost NUMBER  :=  -1.00;
			
			CURSOR cursor_bill_rate (varchar_billing_period_id IN VARCHAR2, varchar_labor_category_id IN VARCHAR2) IS
				SELECT
					lc.labor_category_id,
					lc.labor_category_name,
					lc.non_profit_bill_rate
				FROM
					timecard.labor_category	lc
				WHERE
					lc.billing_period_id		=	varchar_billing_period_id
				AND	lc.labor_category_id		=	varchar_labor_category_id;
		BEGIN
			FOR record_bill_rate IN cursor_bill_rate(varchar_billing_period_id, varchar_labor_category_id) LOOP
				number_calculated_unit_cost :=  record_bill_rate.non_profit_bill_rate;
			END LOOP;
            
			RETURN number_calculated_unit_cost;
		END;
	virtual_arguments_table AS (
			SELECT
				?		AS	billing_period_id,
				?		AS	invoice_section_id
			FROM
				dual
		),
    virtual_invoice_line_table AS (
            SELECT
                DISTINCT
            	tcf.labor_category_id || ' - ' || lc.labor_category_name 						AS  labor_category,
            	INITCAP(tcf.last_name || ', ' || tcf.first_name) || ' (' || tcf.employee_id || ')'    AS	employee,
            	tcf.employee_id,
            	get_billable_hours(tcf.employee_id, vat.billing_period_id)						AS	quantity,
            	get_billable_non_profit_hours(tcf.employee_id, vat.billing_period_id)			AS	non_profit_quantity,
            	get_unit_cost(vat.billing_period_id, tcf.labor_category_id)						AS	unit_cost,
            	get_non_profit_unit_cost(vat.billing_period_id, tcf.labor_category_id)			AS	non_profit_unit_cost
            FROM
                timecard.time_card_fact				tcf,
                timecard.employee_invoice_section	eis,
                timecard.labor_category				lc,
                virtual_arguments_table				vat
            WHERE
				TO_CHAR(tcf.event_date,'yyyy.mm')	=	vat.billing_period_id
			AND	tcf.employee_id						=	eis.employee_id
			AND	eis.billing_period_id				=	vat.billing_period_id
			AND	eis.invoice_section_id				=	vat.invoice_section_id
			AND	eis.labor_category_id				=	tcf.labor_category_id
			AND	lc.labor_category_id				=	tcf.labor_category_id
			AND lc.billing_period_id				=	TO_CHAR(tcf.event_date,'yyyy.mm')
		)
SELECT
    vilt.labor_category,
	vilt.employee,
	vilt.quantity,
	vilt.non_profit_quantity,
	vilt.unit_cost,
	vilt.non_profit_unit_cost,
	vilt.quantity * vilt.unit_cost AS extended_cost,
	vilt.non_profit_quantity * vilt.non_profit_unit_cost AS non_profit_extended_cost
FROM
	virtual_invoice_line_table  vilt
ORDER BY
	vilt.labor_category,
	vilt.employee