create or replace PACKAGE BODY                            TIME_CARD AS
	CURSOR cursor_employee_pay_type_hours(
			varchar_pay_type			IN VARCHAR, 
			varchar_labor_category_id	IN VARCHAR, 
			varchar_employee_id			IN VARCHAR, 
			varchar_event_date			IN VARCHAR
		) IS
		SELECT
			CASE varchar_pay_type
				WHEN 'Bereavement'                  THEN NVL(SUM(tcf.total_paid_duration),0)
				WHEN 'Break'                        THEN NVL(SUM(tcf.unpaid_duration),0)
				WHEN 'Meal'                         THEN NVL(SUM(tcf.unpaid_duration),0)
				WHEN 'Military Leave'               THEN NVL(SUM(tcf.unpaid_duration),0)
				WHEN 'Sick'                         THEN NVL(SUM(tcf.total_paid_duration),0)
				WHEN 'Unpaid Time'                  THEN NVL(SUM(tcf.unpaid_duration),0)
				WHEN 'Vacation'                     THEN NVL(SUM(tcf.total_paid_duration),0)
				WHEN 'Work'                         THEN NVL(SUM(tcf.total_paid_duration),0)
				WHEN 'Work Weather Closure'         THEN NVL(SUM(tcf.total_paid_duration),0)
				WHEN 'Weather-Government Closure'   THEN NVL(SUM(tcf.total_paid_duration),0)
			END         AS  hours_total
		FROM
			timecard.time_card_fact   tcf
		WHERE
			tcf.labor_category_id					=	varchar_labor_category_id
		AND	tcf.employee_id                         =	varchar_employee_id
		AND	TO_CHAR(tcf.event_date,'yyyy.mm.dd')    =	varchar_event_date
		AND	tcf.event_type                          =	varchar_pay_type;

	CURSOR cursor_company_pay_type_hours(			
			varchar_pay_type			IN VARCHAR,
			varchar_time_granularity	IN VARCHAR,
			varchar_period				IN VARCHAR,
			varchar_company_id			IN VARCHAR,
			varchar_labor_category_id	IN VARCHAR
		) IS
		SELECT
			NVL(SUM(tcf.total_paid_duration),0)	pay_type_hours
		FROM
			timecard.time_card_fact   tcf
		WHERE
			tcf.event_type										=	varchar_pay_type
		AND	to_char(tcf.event_date,varchar_time_granularity)	=	varchar_period
		AND	get_company_name(tcf.company_id)  					=	varchar_company_id
		AND	tcf.labor_category_id								=	varchar_labor_category_id;

	CURSOR cursor_labor_category_hours(
			varchar_company_id IN VARCHAR, 
			varchar_time_granularity IN VARCHAR, 
			varchar_period IN VARCHAR,
			varchar_labor_category_id IN VARCHAR
		) IS
		SELECT
			NVL(SUM(tcf.total_paid_duration),0)	labor_category_total
		FROM
			timecard.time_card_fact   tcf
		WHERE
			to_char(tcf.event_date,varchar_time_granularity)		=	varchar_period
		AND	tcf.labor_category_id							=	varchar_labor_category_id
		AND	get_company_name(tcf.company_id)  					=	varchar_company_id
		AND	tcf.event_type									=	'Work';

	CURSOR cursor_non_profit_days (date_event_date	IN	DATE) IS
		SELECT
			bnpe.event_date,
			bnpe.description
		FROM
			timecard.billable_non_profit_event	bnpe
		WHERE
			bnpe.event_date						=	date_event_date;

	CURSOR cursor_labor_category(
			event_date					IN	DATE,
			varchar_labor_category_id	IN	VARCHAR
		) IS
		SELECT
			lc.bill_rate,
			lc.non_profit_bill_rate
		FROM
			timecard.labor_category		lc
		WHERE
			lc.billing_period_id					=	TO_CHAR(event_date, 'yyyy.mm')
		AND	lc.labor_category_id					=	varchar_labor_category_id;
	
	/**
	* Simple cursor for returning company information for the company
	* identified by varchar_company_id.
	*/
	CURSOR cursor_company_information(varchar_company_id IN VARCHAR) IS
		SELECT
			c.company_id,
			c.name,
			c.alternate_name
		FROM
			timecard.company	c
		WHERE
			c.company_id		=	varchar_company_id;
	
	/**
	* Cursor for returning setting information for the setting identified
	* by varchar_setting_id.
	*/
	CURSOR cursor_setting(varchar_setting_id IN VARCHAR) IS
		SELECT
			s.setting_id,
			s.setting_value,
			s.name,
			s.description
		FROM
			timecard.setting	s
		WHERE
			s.setting_id		=	varchar_setting_id;
	
	/**
	* Returns the setting value identified by varchar_setting_id. If the setting is
	* not found use the provided default value varchar_default_value.
	*/
	FUNCTION get_setting(varchar_setting_id IN VARCHAR, varchar_default_value IN VARCHAR) RETURN VARCHAR IS
			varchar_setting_value	VARCHAR(200)	:=	null;
		BEGIN
			FOR record_setting IN cursor_setting(varchar_setting_id) LOOP
				varchar_setting_value	:=	record_setting.setting_value;
			END LOOP;
			
			IF (varchar_setting_value IS NULL) THEN
				varchar_setting_value	:=	varchar_default_value;
			END IF;
			
			RETURN varchar_setting_value;
		EXCEPTION
			WHEN OTHERS THEN
				RETURN sqlerrm;
		END get_setting;
		
	/**
	* Returns a company name based on the given company identifier. The
	* name returned will also be determined by the application setting 
	* company_display_name.
	*/
	FUNCTION get_company_name(
			varchar_company_id				IN	VARCHAR
		) RETURN VARCHAR IS
			varchar_company_name		VARCHAR(100)	:=	'Unknown';
			varchar_company_display_name	VARCHAR(100)	:=	'name';
		BEGIN
			/**
			* Get the application setting for company_display_name. If it has
			* not been set use the default value of 'name' for this function.
			*/
			varchar_company_display_name		:=	get_setting('company_display_name','name');
			
			FOR record_company_information IN cursor_company_information(varchar_company_id) LOOP
				IF (varchar_company_display_name = 'name') THEN
					varchar_company_name	:=	record_company_information.name;
				ELSE
					varchar_company_name	:=	record_company_information.alternate_name;
				END IF;
			END LOOP;
			
			RETURN varchar_company_name;
		EXCEPTION
			WHEN OTHERS THEN
				RAISE;
		END get_company_name;

	/**
	* Returns a character value indicating whether or not
	* the date was a Profit or Non-Profit date. If it cannot
	* ascertained whether it was a Profit or Non-Profit date
	* the value Unknown will be returned.
	*/
	FUNCTION get_billable_type (
			event_date					IN	DATE
		) RETURN VARCHAR IS
			varchar_billable_type		VARCHAR(100)	:=	'Profit';
		BEGIN
			FOR record_non_profit_days IN cursor_non_profit_days(event_date) LOOP
				varchar_billable_type	:=	'Non-Profit';
			END LOOP;

			RETURN varchar_billable_type;
		EXCEPTION
			WHEN OTHERS THEN
				RAISE;
		END get_billable_type;

	/**
	* Returns the appropriate bill rate given the event date
	* and labor category identifier.
	*/
	FUNCTION get_bill_rate(
			event_date					IN	DATE,
			varchar_labor_category_id	IN	VARCHAR
		) RETURN NUMBER IS
			number_bill_rate			NUMBER			:=	0;
			varchar_billable_type		VARCHAR(100)	:=	get_billable_type(event_date);
		BEGIN
			FOR record_labor_category IN cursor_labor_category(event_date, varchar_labor_category_id) LOOP
				IF (varchar_billable_type = 'Profit') THEN
					number_bill_rate		:=	record_labor_category.bill_rate;
				ELSIF (varchar_billable_type = 'Non-Profit') THEN
					number_bill_rate		:=	record_labor_category.non_profit_bill_rate;
				ELSIF (varchar_billable_type = 'Unknown') THEN
					number_bill_rate		:=	-1;
				ELSE
					RAISE_APPLICATION_ERROR(-20008, 'Unhandled billable type.');
				END IF; 
			END LOOP;

			RETURN number_bill_rate;
		EXCEPTION
			WHEN OTHERS THEN
				RETURN -1;
		END get_bill_rate;

	/**
	* Given a billing period identifier (varchar_billing_period_id)
	* and a labor category identifier (varchar_labor_category_id) find
	* and return the associated labor category record. IF no record
	* can be found return NULL.
	*/
	FUNCTION get_labor_category(
			varchar_billing_period_id	IN	VARCHAR,
			varchar_labor_category_id	IN	VARCHAR
		) RETURN TIMECARD.LABOR_CATEGORY%ROWTYPE IS
			record_labor_category	TIMECARD.LABOR_CATEGORY%ROWTYPE;
		BEGIN
			SELECT
				lc.*
			INTO
				record_labor_category
			FROM
				timecard.labor_category				lc
			WHERE
				lc.billing_period_id			=	varchar_billing_period_id
			AND	lc.labor_category_id			=	varchar_labor_category_id;

			RETURN record_labor_category;
		EXCEPTION
			WHEN NO_DATA_FOUND THEN
				RETURN NULL;
		END get_labor_category;

	FUNCTION get_pay_type_hours(
			varchar_pay_type IN VARCHAR, 
			varchar_labor_category_id IN VARCHAR, 
			varchar_employee_id IN VARCHAR, 
			varchar_event_date IN VARCHAR
		) RETURN NUMBER AS
			number_hours_total       NUMBER  := 0;
		BEGIN
			FOR record_employee_pay_type_hours IN cursor_employee_pay_type_hours(varchar_pay_type, varchar_labor_category_id, varchar_employee_id, varchar_event_date) LOOP
				number_hours_total   :=  number_hours_total + record_employee_pay_type_hours.hours_total;
			END LOOP;
			RETURN number_hours_total;
		END get_pay_type_hours;

	FUNCTION get_pay_type_hours(
			varchar_pay_type IN VARCHAR,
			varchar_time_granularity IN VARCHAR,
			varchar_period IN VARCHAR,
			varchar_company_id IN VARCHAR,
			varchar_labor_category_id IN VARCHAR
		) RETURN NUMBER AS
			number_pay_type_total	NUMBER		:=	0;
		BEGIN
			FOR record_company_pay_type_hours IN cursor_company_pay_type_hours(varchar_pay_type, varchar_time_granularity, varchar_period, varchar_company_id, varchar_labor_category_id) LOOP
				number_pay_type_total	:=	number_pay_type_total + record_company_pay_type_hours.pay_type_hours;
			END LOOP;
			RETURN number_pay_type_total;
		END;

	FUNCTION get_labor_category_hours (
			varchar_time_granularity IN VARCHAR, 
			varchar_period IN VARCHAR, 
			varchar_company_id IN VARCHAR, 
			varchar_labor_category_id IN VARCHAR
		) RETURN NUMBER IS
			number_labor_category_total	NUMBER	:=	0;	
		BEGIN
			FOR record_labor_category_total IN cursor_labor_category_hours(varchar_company_id, varchar_time_granularity, varchar_period, varchar_labor_category_id) LOOP
				number_labor_category_total	:=	number_labor_category_total + record_labor_category_total.labor_category_total;
			END LOOP;
			RETURN number_labor_category_total;
		END;
END TIME_CARD;
/