CREATE OR REPLACE PACKAGE TIME_CARD AS
	/**
	* Returns the setting value identified by varchar_setting_id. If the setting is
	* not found use the provided default value varchar_default_value.
	* @param varchar_setting_id identifier for the setting for which the setting
	*			value will be returned
	* @param varchar_default_value value to be returned if the setting is not found
	*/
	FUNCTION get_setting(
			varchar_setting_id IN VARCHAR, 
			varchar_default_value IN VARCHAR
		) RETURN VARCHAR;

	/**
	* Returns a company name based on the given company identifier. The value
	* returned is calculated based on the setting company_display_name in the
	* SETTING.
	*/
	FUNCTION get_company_name(
			varchar_company_id				IN	VARCHAR
		) RETURN VARCHAR;
	
	/**
	* Returns a character value indicating whether or not
	* the date was a Profit or Non-Profit date. If it cannot
	* ascertained whether it was a Profit or Non-Profit date
	* the value Unknown will be returned.
	*/
	FUNCTION get_billable_type (
			event_date					IN	DATE
		) RETURN VARCHAR;

	/**
	* Returns the appropriate bill rate given the event date
	* and labor category identifier.
	*/
	FUNCTION get_bill_rate(
			event_date					IN	DATE,
			varchar_labor_category_id	IN	VARCHAR
		) RETURN NUMBER;

	/**
	* Given a billing period identifier (varchar_billing_period_id)
	* and a labor category identifier (varchar_labor_category_id) find
	* and return the associated labor category record. IF no record
	* can be found return NULL.
	*/
	FUNCTION get_labor_category(
			varchar_billing_period_id	IN	VARCHAR,
			varchar_labor_category_id	IN	VARCHAR
		) RETURN TIMECARD.LABOR_CATEGORY%ROWTYPE;

	/**
	* Returns the number of hours recorded for the given pay type
	* for the given employee in the given labor category on the given
	* date (varchar_event_date).
	*/
	FUNCTION get_pay_type_hours(
			varchar_pay_type IN VARCHAR, 
			varchar_labor_category_id IN VARCHAR, 
			varchar_employee_id IN VARCHAR, 
			varchar_event_date IN VARCHAR
		) RETURN NUMBER;

	/**
	* Returns the sum of hours recorded for the given company
	* (varchar_company_id) in the given period (varchar_period).
	* The sum returned will be based on only the time recorded
	* that matches the pay type parameter value (varchar_pay_type).
	*/
	FUNCTION get_pay_type_hours(
			varchar_pay_type IN VARCHAR,
			varchar_time_granularity IN VARCHAR,
			varchar_period IN VARCHAR,
			varchar_company_id IN VARCHAR,
			varchar_labor_category_id IN VARCHAR
		) RETURN NUMBER;

	/**
	* Returns the sum of billable hours recorded for the given company
	* (varchar_company_id) in the given period (varchar_period).
	*/
	FUNCTION get_labor_category_hours (
			varchar_time_granularity IN VARCHAR, 
			varchar_period IN VARCHAR, 
			varchar_company_id IN VARCHAR, 
			varchar_labor_category_id IN VARCHAR
		) RETURN NUMBER;
END TIME_CARD;
/