-- Required for the creation of common users in the database.
ALTER SESSION SET "_ORACLE_SCRIPT"=true;

-- Drop the user account that will be used for storing PayChex exports.
DROP USER timecard CASCADE;

-- Create the user account that will be used for storing PayChex exports.
CREATE USER timecard
	IDENTIFIED BY your_password_here
	DEFAULT TABLESPACE USERS
	TEMPORARY TABLESPACE TEMP;

-- Ensure that the account has basic privileges.
GRANT CREATE SESSION TO timecard;
GRANT CONNECT TO timecard;
GRANT CREATE TABLE TO timecard; 
GRANT UNLIMITED TABLESPACE TO timecard;

-- Connect to the Oracle database using the recently created account.

-- Drop the company and fact table of time card data.
DROP TABLE timecard.log CASCADE CONSTRAINTS;
DROP TABLE timecard.company CASCADE CONSTRAINTS;
DROP TABLE timecard.time_card_fact CASCADE CONSTRAINTS;
DROP TABLE timecard.labor_category CASCADE CONSTRAINTS;
DROP TABLE timecard.billing_period CASCADE CONSTRAINTS;
DROP TABLE timecard.billable_non_profit_event CASCADE CONSTRAINTS;
DROP TABLE timecard.employee_invoice_section CASCADE CONSTRAINTS;
DROP TABLE timecard.invoice_section CASCADE CONSTRAINTS;
DROP TABLE timecard.invoice_metadata CASCADE CONSTRAINTS;
DROP TABLE timecard.employee CASCADE CONSTRAINTS;
DROP TABLE timecard.setting CASCADE CONSTRAINTS;

CREATE TABLE timecard.setting (
	setting_id					VARCHAR2(100)	NOT NULL,
	setting_value				VARCHAR2(250)	NOT NULL,
	name						VARCHAR2(100)	NOT NULL,
	desciption					VARCHAR2(200)	NOT NULL,
	PRIMARY KEY (setting_id)
);

-- Create a table for logging application events.
CREATE TABLE timecard.log (
	log_id						VARCHAR2(100)	DEFAULT (sys_guid() || '') NOT NULL,
	timestamp_logged			VARCHAR2(40)	DEFAULT TO_CHAR(current_timestamp,'yyyy.mm.dd.hh24.mi.ssff3') NOT NULL,
	log_type					VARCHAR2(100)	DEFAULT 'INFO' NOT NULL,
	message						VARCHAR2(1000)	NOT NULL,
	PRIMARY KEY (log_id)
);

-- Create a table for the companies that will be supported in data loads.
CREATE TABLE timecard.company (
	company_id					VARCHAR2(100),
	name						VARCHAR2(100),
	altername_name				VARCHAR2(100),
	PRIMARY KEY (company_id)	
);

INSERT INTO timecard.company c (c.company_id, c.name, c.alternate_name) VALUES ('XSI','Xtreme Solutions, Inc.','Google');
INSERT INTO timecard.company c (c.company_id, c.name, c.alternate_name) VALUES ('AppleOne','AppleOne','Amazone');
INSERT INTO timecard.company c (c.company_id, c.name, c.alternate_name) VALUES ('CMT','CMT','Microsoft');
COMMIT;

-- Create the time card fact table.
CREATE TABLE timecard.time_card_fact (
    TIME_CARD_FACT_ID			VARCHAR2(100)	DEFAULT (SYS_GUID() || '')	NOT NULL,
    COMPANY_ID					VARCHAR2(100)								NOT	NULL,
    EMPLOYEE_ID					VARCHAR2(10)								NOT NULL,
    FIRST_NAME					VARCHAR2(100),
    LAST_NAME					VARCHAR2(100),
    EVENT_DATE					DATE										NOT NULL,
    EVENT_TYPE					VARCHAR2(100),
    REGULAR_DURATION			NUMBER(8,2),
    UNPAID_DURATION				NUMBER(8,2),
    TOTAL_PAID_DURATION			NUMBER(8,2),
    PROJECT_ID					VARCHAR2(20),
    PROJECT_NAME				VARCHAR2(100),
    LABOR_CATEGORY_ID			VARCHAR2(20),
    DEPARTMENT_ID				VARCHAR2(20),
    DEPARTMENT_NAME				VARCHAR2(100),
    HOURLY_RATE					NUMBER(8,2)
);

ALTER TABLE timecard.time_card_fact ADD CONSTRAINT fk_time_card_fact_company
	FOREIGN KEY (company_id) 
	REFERENCES timecard.company (company_id) ON DELETE CASCADE;

CREATE TABLE timecard.billing_period (
  billing_period_id VARCHAR(100),
  caption VARCHAR(250),
  PRIMARY KEY (billing_period_id)
);

INSERT INTO timecard.billing_period bp (bp.billing_period_id, bp.caption) VALUES ('2018.12','2018.12');
INSERT INTO timecard.billing_period bp (bp.billing_period_id, bp.caption) VALUES ('2019.01','2019.01');
INSERT INTO timecard.billing_period bp (bp.billing_period_id, bp.caption) VALUES ('2019.02','2019.02');
INSERT INTO timecard.billing_period bp (bp.billing_period_id, bp.caption) VALUES ('2019.03','2019.03');
INSERT INTO timecard.billing_period bp (bp.billing_period_id, bp.caption) VALUES ('2019.04','2019.04');
INSERT INTO timecard.billing_period bp (bp.billing_period_id, bp.caption) VALUES ('2019.05','2019.05');
INSERT INTO timecard.billing_period bp (bp.billing_period_id, bp.caption) VALUES ('2019.06','2019.06');
INSERT INTO timecard.billing_period bp (bp.billing_period_id, bp.caption) VALUES ('2019.07','2019.07');
INSERT INTO timecard.billing_period bp (bp.billing_period_id, bp.caption) VALUES ('2019.08','2019.08');
INSERT INTO timecard.billing_period bp (bp.billing_period_id, bp.caption) VALUES ('2019.09','2019.09');
INSERT INTO timecard.billing_period bp (bp.billing_period_id, bp.caption) VALUES ('2019.10','2019.10');
INSERT INTO timecard.billing_period bp (bp.billing_period_id, bp.caption) VALUES ('2019.11','2019.11');
INSERT INTO timecard.billing_period bp (bp.billing_period_id, bp.caption) VALUES ('2019.12','2019.12');
COMMIT;

CREATE TABLE timecard.billable_non_profit_event (
	event_date		DATE,
	description		VARCHAR(250),
	PRIMARY KEY (event_date)
);

INSERT INTO timecard.billable_non_profit_event bnpe (bnpe.event_date, bnpe.description) VALUES (('08-JAN-2019'),'Jan Test Date 1');
INSERT INTO timecard.billable_non_profit_event bnpe (bnpe.event_date, bnpe.description) VALUES (('09-JAN-2019'),'Jan Test Date 2');
INSERT INTO timecard.billable_non_profit_event bnpe (bnpe.event_date, bnpe.description) VALUES (('12-FEB-2019'),'Feb Test Date 1');
INSERT INTO timecard.billable_non_profit_event bnpe (bnpe.event_date, bnpe.description) VALUES (('05-MAR-2019'),'Mar Test Date 1');
INSERT INTO timecard.billable_non_profit_event bnpe (bnpe.event_date, bnpe.description) VALUES (('23-APR-2019'),'Apr Test Date 1');
COMMIT;

CREATE TABLE timecard.labor_category (
	billing_period_id			VARCHAR(100),
	labor_category_id			VARCHAR(100),
	labor_category_name			VARCHAR(100),
	bill_rate					NUMBER(8,2),
	non_profit_bill_rate		NUMBER(8,2),
	PRIMARY KEY (billing_period_id, labor_category_id)
);

INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AA','Supervisor',62.96,59.96);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AB','Team Lead ',46.91,44.98);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AC','Program Support Analyst Level I',56.74,54.04);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AD','Program Support Analyst Level II',68.02,64.78);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AE','Business Process Analyst Level I',46.91,44.68);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AF','Business Process Analyst Level II',56.74,54.04);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AG','Records Support Associate Level I',34.5,32.86);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AGO','Records Support Associate Level I OT',51.75,51.75);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AH','Records Support Associate Level II',38.34,36.51);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AHO','Records Support Associate Level II OT',57.51,57.51);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AI','Records Services Cashier',34.5,32.86);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AIO','Records Services Cashier OT',51.75,51.75);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AJ','Labor Relations Specialist',95.57,91.02);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AK','Fraud Associate Level I',34.5,32.86);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AKO','Fraud Associate Level I OT',51.75,51.75);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AL','Fraud Associate Level II',42.46,40.44);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001ALO','Fraud Associate Level II OT',63.69,63.69);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AM','Training Coordinator',51.65,49.19);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AN','SharePoint Administrator',99.76,95.01);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AO','Executive Assistant - Washington DC',62.42,59.45);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AOC','Executive Assistant - Capitol Region',62.42,59.45);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AOS','Executive Assistant - South Central',64.14,61.09);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AOW','Executive Assistant - Western',63.58,60.55);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AON','Executive Assistant - North Eastern',62.07,59.11);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AP','Administrative Support Level I',42.46,40.44);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001APO','Administrative Support Level I OT',63.69,63.69);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AQ','Administrative Support Level II',46.91,44.68);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2018.12','0001AQO','Administrative Support Level II OT',70.37,70.37);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AA','Supervisor',62.96,59.96);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AB','Team Lead ',46.91,44.98);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AC','Program Support Analyst Level I',56.74,54.04);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AD','Program Support Analyst Level II',68.02,64.78);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AE','Business Process Analyst Level I',46.91,44.68);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AF','Business Process Analyst Level II',56.74,54.04);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AG','Records Support Associate Level I',34.5,32.86);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AGO','Records Support Associate Level I OT',51.75,51.75);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AH','Records Support Associate Level II',38.34,36.51);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AHO','Records Support Associate Level II OT',57.51,57.51);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AI','Records Services Cashier',34.5,32.86);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AIO','Records Services Cashier OT',51.75,51.75);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AJ','Labor Relations Specialist',95.57,91.02);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AK','Fraud Associate Level I',34.5,32.86);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AKO','Fraud Associate Level I OT',51.75,51.75);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AL','Fraud Associate Level II',42.46,40.44);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001ALO','Fraud Associate Level II OT',63.69,63.69);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AM','Training Coordinator',51.65,49.19);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AN','SharePoint Administrator',99.76,95.01);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AO','Executive Assistant - Washington DC',62.42,59.45);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AOC','Executive Assistant - Capitol Region',62.42,59.45);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AOS','Executive Assistant - South Central',64.14,61.09);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AOW','Executive Assistant - Western',63.58,60.55);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AON','Executive Assistant - North Eastern',62.07,59.11);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AP','Administrative Support Level I',42.46,40.44);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001APO','Administrative Support Level I OT',63.69,63.69);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AQ','Administrative Support Level II',46.91,44.68);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.01','0001AQO','Administrative Support Level II OT',70.37,70.37);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AA','Supervisor',62.96,59.96);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AB','Team Lead ',46.91,44.98);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AC','Program Support Analyst Level I',56.74,54.04);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AD','Program Support Analyst Level II',68.02,64.78);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AE','Business Process Analyst Level I',46.91,44.68);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AF','Business Process Analyst Level II',56.74,54.04);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AG','Records Support Associate Level I',34.5,32.86);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AGO','Records Support Associate Level I OT',51.75,51.75);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AH','Records Support Associate Level II',38.34,36.51);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AHO','Records Support Associate Level II OT',57.51,57.51);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AI','Records Services Cashier',34.5,32.86);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AIO','Records Services Cashier OT',51.75,51.75);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AJ','Labor Relations Specialist',95.57,91.02);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AK','Fraud Associate Level I',34.5,32.86);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AKO','Fraud Associate Level I OT',51.75,51.75);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AL','Fraud Associate Level II',42.46,40.44);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001ALO','Fraud Associate Level II OT',63.69,63.69);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AM','Training Coordinator',51.65,49.19);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AN','SharePoint Administrator',99.76,95.01);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AO','Executive Assistant - Washington DC',62.42,59.45);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AOC','Executive Assistant - Capitol Region',62.42,59.45);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AOS','Executive Assistant - South Central',64.14,61.09);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AOW','Executive Assistant - Western',63.58,60.55);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AON','Executive Assistant - North Eastern',62.07,59.11);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AP','Administrative Support Level I',42.46,40.44);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001APO','Administrative Support Level I OT',63.69,63.69);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AQ','Administrative Support Level II',46.91,44.68);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.02','0001AQO','Administrative Support Level II OT',70.37,70.37);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AA','Supervisor',62.96,59.96);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AB','Team Lead ',46.91,44.98);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AC','Program Support Analyst Level I',56.74,54.04);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AD','Program Support Analyst Level II',68.02,64.78);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AE','Business Process Analyst Level I',46.91,44.68);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AF','Business Process Analyst Level II',56.74,54.04);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AG','Records Support Associate Level I',34.5,32.86);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AGO','Records Support Associate Level I OT',51.75,51.75);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AH','Records Support Associate Level II',38.34,36.51);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AHO','Records Support Associate Level II OT',57.51,57.51);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AI','Records Services Cashier',34.5,32.86);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AIO','Records Services Cashier OT',51.75,51.75);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AJ','Labor Relations Specialist',95.57,91.02);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AK','Fraud Associate Level I',34.5,32.86);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AKO','Fraud Associate Level I OT',51.75,51.75);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AL','Fraud Associate Level II',42.46,40.44);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001ALO','Fraud Associate Level II OT',63.69,63.69);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AM','Training Coordinator',51.65,49.19);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AN','SharePoint Administrator',99.76,95.01);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AO','Executive Assistant - Washington DC',62.42,59.45);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AOC','Executive Assistant - Capitol Region',62.42,59.45);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AOS','Executive Assistant - South Central',64.14,61.09);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AOW','Executive Assistant - Western',63.58,60.55);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AON','Executive Assistant - North Eastern',62.07,59.11);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AP','Administrative Support Level I',42.46,40.44);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001APO','Administrative Support Level I OT',63.69,63.69);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AQ','Administrative Support Level II',46.91,44.68);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.03','0001AQO','Administrative Support Level II OT',70.37,70.37);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AA','Supervisor',62.96,59.96);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AB','Team Lead ',46.91,44.98);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AC','Program Support Analyst Level I',56.74,54.04);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AD','Program Support Analyst Level II',68.02,64.78);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AE','Business Process Analyst Level I',46.91,44.68);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AF','Business Process Analyst Level II',56.74,54.04);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AG','Records Support Associate Level I',34.5,32.86);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AGO','Records Support Associate Level I OT',51.75,51.75);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AH','Records Support Associate Level II',38.34,36.51);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AHO','Records Support Associate Level II OT',57.51,57.51);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AI','Records Services Cashier',34.5,32.86);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AIO','Records Services Cashier OT',51.75,51.75);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AJ','Labor Relations Specialist',95.57,91.02);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AK','Fraud Associate Level I',34.5,32.86);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AKO','Fraud Associate Level I OT',51.75,51.75);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AL','Fraud Associate Level II',42.46,40.44);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001ALO','Fraud Associate Level II OT',63.69,63.69);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AM','Training Coordinator',51.65,49.19);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AN','SharePoint Administrator',99.76,95.01);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AO','Executive Assistant - Washington DC',62.42,59.45);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AOC','Executive Assistant - Capitol Region',62.42,59.45);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AOS','Executive Assistant - South Central',64.14,61.09);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AOW','Executive Assistant - Western',63.58,60.55);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AON','Executive Assistant - North Eastern',62.07,59.11);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AP','Administrative Support Level I',42.46,40.44);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001APO','Administrative Support Level I OT',63.69,63.69);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AQ','Administrative Support Level II',46.91,44.68);
INSERT INTO timecard.labor_category lc (lc.billing_period_id, lc.labor_category_id, lc.labor_category_name, lc.bill_rate, lc.non_profit_bill_rate) VALUES ('2019.04','0001AQO','Administrative Support Level II OT',70.37,70.37);
COMMIT;

CREATE TABLE timecard.invoice_section (
	billing_period_id VARCHAR(100),
	invoice_section_id VARCHAR(100),
	caption VARCHAR(250),
	PRIMARY KEY (billing_period_id, invoice_section_id)
);

ALTER TABLE timecard.invoice_section ADD CONSTRAINT fk_invoice_sctn_bill_period
	FOREIGN KEY (billing_period_id)
	REFERENCES timecard.billing_period (billing_period_id);

CREATE TABLE timecard.invoice_metadata (
	invoice_metadata_id			VARCHAR(100)	DEFAULT (SYS_GUID() || '')	NOT NULL,
	billing_period_id			VARCHAR(100)	DEFAULT 'YYYY.MM',
	logo_location				VARCHAR(300)	DEFAULT 'http://biftechnologies.com/brainjack/timecard/logo/xsi.jpg',
	invoice_name				VARCHAR(100)	DEFAULT 'XSI.{section_name}.{billing_period_id}',
	duns_number					VARCHAR(20)		DEFAULT	'827980942',
	requisition_number			VARCHAR(20)		DEFAULT '1044806258',
	contract_number				VARCHAR(50)		DEFAULT '10101010101',
	order_number				VARCHAR(20)		DEFAULT '19AQMM18F5384',
	task_order_number			VARCHAR(50)		DEFAULT 'TO1234567890',
	invoice_number				VARCHAR(100)	DEFAULT 'XTR-XX-XX-XX',
	payment_terms				VARCHAR(100)	DEFAULT 'Net 10-15',
	date_of_invoice				VARCHAR(30)		DEFAULT TO_CHAR(SYSDATE,'yyyy.mm.dd'),
	list_of_far					VARCHAR(30)		DEFAULT 'FAR001, FAR002',
	vendor_address				VARCHAR(4000)	DEFAULT 'Xtreme Solutions, Inc.\n2859 Paces Ferry Rd SE, Suite 1100\nAtlanta, GA 30339-6207\n(404)883-2000',
	customer_bill_to_address	VARCHAR(4000)	DEFAULT 'Department Of State\nGlobal Financial Operations (RM/GFS/GFO)\nOffice of Claims (GFO/C)\nCharleston Financial Service Center\nPost Office Box 15008\nCharleston, SC 29415-5008',
	remit_to_address			VARCHAR(4000)	DEFAULT 'Xtreme Solutions, Inc.\nAttn: Hervia M. Ingram, Jr.\n2859 Paces Ferry Road, Suite 1100\nAtlanta, GA 30339-6207\nhingram@xtremesolutions-inc.com\n404-883-2000',
	remit_contract_information	VARCHAR(4000)	DEFAULT 'Devance Boseman, Account Manager, 2859 Paces Ferry Road, Suite 1100, Atlanta, GA 30339-6207\naccounting@xtremesolutions-inc.com\n404-883-2000',
	remit_method_information	VARCHAR(4000)	DEFAULT 'PLEASE REMIT VIA ACH\nBank: Bank of America\nABA# 061000052\nAccount# 334008719825'
);

ALTER TABLE timecard.invoice_metadata ADD CONSTRAINT pk_invoice_metadata
	PRIMARY KEY (invoice_metadata_id);

ALTER TABLE timecard.invoice_metadata ADD CONSTRAINT fk_metadata_to_billing_period
	FOREIGN KEY (billing_period_id)
	REFERENCES timecard.billing_period (billing_period_id) ON DELETE CASCADE;

CREATE TABLE timecard.employee_invoice_section (
	billing_period_id			VARCHAR(100),
	labor_category_id			VARCHAR(100),
	invoice_section_id			VARCHAR(100),
	employee_id					VARCHAR(100),
	PRIMARY KEY (labor_category_id, invoice_section_id, employee_id)
);

ALTER TABLE timecard.employee_invoice_section ADD CONSTRAINT fk_emp_invoice_section
	FOREIGN KEY (billing_period_id, invoice_section_id)
	REFERENCES timecard.invoice_section (billing_period_id, invoice_section_id) ON DELETE CASCADE;

CREATE TABLE timecard.employee (
	employee_id				VARCHAR(100),
	first_name				VARCHAR(100),
	last_name					VARCHAR(100),
	PRIMARY KEY (employee_id)
);

ALTER TABLE timecard.employee_invoice_section ADD CONSTRAINT fk_emp_inv_sect_to_emp
	FOREIGN KEY (employee_id)
	REFERENCES timecard.employee (employee_id);

-- Grant privilges required for BrainJack IDE
GRANT INSERT, UPDATE, DELETE, SELECT ON timecard.LOG						TO INSIGHT;
GRANT INSERT, UPDATE, DELETE, SELECT ON timecard.BILLABLE_NON_PROFIT_EVENT	TO INSIGHT;
GRANT INSERT, UPDATE, DELETE, SELECT ON timecard.LABOR_CATEGORY				TO INSIGHT;
GRANT INSERT, UPDATE, DELETE, SELECT ON timecard.TIME_CARD_FACT				TO INSIGHT;
GRANT INSERT, UPDATE, DELETE, SELECT ON timecard.BILLING_PERIOD				TO INSIGHT;
GRANT INSERT, UPDATE, DELETE, SELECT ON timecard.INVOICE_SECTION			TO INSIGHT;
GRANT INSERT, UPDATE, DELETE, SELECT ON timecard.INVOICE_METADATA			TO INSIGHT;
GRANT INSERT, UPDATE, DELETE, SELECT ON timecard.EMPLOYEE					TO INSIGHT;
GRANT INSERT, UPDATE, DELETE, SELECT ON timecard.EMPLOYEE_INVOICE_SECTION	TO INSIGHT;
GRANT INSERT, UPDATE, DELETE, SELECT ON timecard.SETTING					TO INSIGHT;
